#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2
visibility:           public
id:                   data-dword-0.3.2-3b11v7XOhk8HpPCDiUnf7B
key:                  data-dword-0.3.2-3b11v7XOhk8HpPCDiUnf7B
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  8719b191c01a440af8c83a9b2855ab7d
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-dword-0.3.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-dword-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/data-dword-0.3.2
hs-libraries:         HSdata-dword-0.3.2-3b11v7XOhk8HpPCDiUnf7B
depends:
    base-4.14.2.0 data-bword-0.1.0.1-AULvfz1x2yEHefd7vgdlIA
    ghc-prim-0.6.1 hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

